#
# spec file for package uClibc
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Url:            http://www.uclibc.org/

Name:           uClibc
Version:        0.9.33.2
Release:        18.18
Summary:        A full-featured C library optimized for size
License:        LGPL-2.1+
Group:          System/Libraries
BuildRequires:  linux-kernel-headers
BuildRequires:  ncurses-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Source0:        uClibc-0.9.33.2.tar.bz2
ExcludeArch:    s390 s390x ppc64 ppc64le
%ifarch ppc
Source1:        config.ppc
%endif
%ifarch x86_64
Source1:        config.x86_64
%endif
%ifarch %ix86
Source1:        config.i386
%endif
%ifarch ia64
Source1:        config.ia64
%endif
%ifarch armv5tel
Source1:        config.armel
%endif
%ifarch %arm
Source1:        config.armhl
%endif
%ifarch m68k
Source1:        config.m68k
%endif
Source2:        gcc-uClibc.in
Source3:        README.SUSE
Patch0:         uClibc.Makefile-gcc-uClibc-wrapper.patch
Patch1:         arm-fixclone.patch

%description
A full-featured C library optimized for size. uClibc (pronounced
yew-see-lib-see) is a C library for developing embedded Linux systems.
It is much smaller than the GNU C Library, but nearly all applications
supported by glibc also work perfectly with uClibc. Porting
applications from glibc to uClibc typically involves just recompiling
the source code. uClibc even supports shared libraries and threading.



Authors:
--------
    Erik Andersen <andersen@codepoet.org>

%prep
%setup -q
%patch0 -p1
%patch1 -p1
cp %{S:1} .config
cp %{S:2} gcc-uClibc.in
cp %{S:3} README.SUSE

%build
# compress man pages
gzip -9 docs/man/*
# make
make oldconfig
make %{?_smp_mflags}
# make with debug
#make V=1 make %{?_smp_mflags}

%clean 
#rm -rf $RPM_BUILD_ROOT

%install
make install DESTDIR=$RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT/usr/bin/
mkdir -p $RPM_BUILD_ROOT/%{_docdir}/uClibc
install -m 755 gcc-uClibc $RPM_BUILD_ROOT/usr/bin
install -m 644 %{S:3} $RPM_BUILD_ROOT/%{_docdir}/uClibc
sed -i "s,$RPM_BUILD_ROOT,,g" $RPM_BUILD_ROOT/usr/bin/gcc-uClibc

%files 
%defattr(-,root,root)
%doc README.* COPYING.LIB* DEDICATION.mjn3 MAINTAINERS INSTALL TODO docs/*
#These will come when shared library support will be enabled
#%dir /usr/lib/*-linux-uclibc/lib
#/usr/lib/*-linux-uclibc/lib/*.so.*

%package -n uClibc-devel
Requires:       %{name} = %{version}
Summary:        a full-featured C library optimized for size
Group:          System/Libraries
Recommends:     gcc

%description -n uClibc-devel
uClibc (aka µClibc/pronounced yew-see-lib-see) is a C library for
developing embedded Linux systems. It is much smaller than the GNU C
Library, but nearly all applications supported by glibc also work
perfectly with uClibc. Porting applications from glibc to uClibc
typically involves just recompiling the source code. uClibc even
supports shared libraries and threading.



Authors:
--------
    Erik Andersen <andersen@codepoet.org>

%files -n uClibc-devel
%defattr(-,root,root)
%_bindir/gcc-uClibc
%dir /usr/lib/*-linux-uclibc
%dir /usr/lib/*-linux-uclibc/usr
%dir /usr/lib/*-linux-uclibc/usr/lib
%dir /usr/lib/*-linux-uclibc/usr/include
/usr/lib/*-linux-uclibc/usr/lib/*.[ao]
/usr/lib/*-linux-uclibc/usr/include/*
#These will come when shared library support will be enabled
#/usr/lib/*-linux-uclibc/lib/*.so
#/usr/lib/*-linux-uclibc/usr/lib/*.so

%changelog
* Mon Aug  3 2015 normand@linux.vnet.ibm.com
- ExcludeArch ppc64le as already done for ppc64
* Mon Mar 16 2015 bwiedemann@suse.com
- Disable stack-protector to fix segfaults (bnc#781686)
* Fri Jan 30 2015 bwiedemann@suse.com
- Recommend gcc as the gcc-uClibc needs it
* Wed Nov 19 2014 Led <ledest@gmail.com>
- fix shebang in gcc-uClibc script that contains bash-specific
  constructions
* Thu Oct 30 2014 guillaume@opensuse.org
- Fix armv6 build
* Wed Nov  6 2013 idonmez@suse.com
- Fix spec file encoding to be UTF-8
* Mon Oct 28 2013 schwab@suse.de
- config.m68k: config file for m68k
* Tue Dec 18 2012 idonmez@suse.com
- Move uClibc-gcc into -devel package so that it can actually work
  bnc#781685
* Thu Sep 27 2012 idonmez@suse.com
- Regenerate the config file and enable the following
  to fix busybox-static compilation
  * UCLIBC_SUSV3_LEGACY
  * UCLIBC_SUSV3_LEGACY_MACROS
  * UCLIBC_SUSV4_LEGACY
  * UCLIBC_HAS_RESOLVER_SUPPORT
* Tue Jun 12 2012 agraf@suse.com
- update to uClibc 0.9.33.2
  - fixes arm build
* Mon Oct 10 2011 agraf@suse.de
- fix armv7 build
* Mon Oct  3 2011 mhrusecky@suse.cz
- fixed build on arm
* Fri May 27 2011 idonmez@novell.com
- Add uClibc.ppc-invalid-size-directive.patch,
  uClibc.i386-invalid-size-directive.patch,
  uClibc.x86_64-invalid-size-directive.patch: remove invalid .size
  directives from assembly files
* Sun Oct 31 2010 jengelh@medozas.de
- Use %%_smp_mflags
* Sun Jun  7 2009 ro@suse.de
- rename getline to my_getline to avoid collision with function
  from glibc
* Sun Apr 19 2009 ro@suse.de
- update to bugfix release 0.9.30.1
* Fri Dec 19 2008 sassmann@suse.de
- enable pthread support on i386, x86_64, ppc and ia64
- tweak config files
- add:
  uClibc.fix-pthread-warnings.patch: fix "warning: no previous
  prototype for ..."
  uClibc.ppc-fix-nested-extern-declaration.patch: fix "warning:
  nested extern declaration of '__illegally_sized_syscall_arg1'"
* Thu Dec 18 2008 sassmann@suse.de
- add uClibc.ia64-INTERNAL_SYSCALL-conversion.patch: use
  INTERNAL_SYSCALL on ia64
* Tue Dec 16 2008 sassmann@suse.de
- add:
  uClibc.ia64-fake-getpgrp-syscall.patch: getpgrp is not available
  on ia64 this patch emulates it.
  uClibc.ia64-use-sched_setaffinity-if-present.patch: make use
  of syscall sched_setaffinity
* Mon Dec 15 2008 sassmann@suse.de
- add uClibc.static-segfault-fix.patch: fix segfault of static
  binaries that don't stdio functions
* Thu Nov 13 2008 sassmann@suse.de
- update to version 0.9.30
  * for full changelog check
    http://www.uclibc.org/downloads/ChangeLog-0.9.29_0.9.30
- remove obsolete patch uClibc.compile-fix.patch
* Fri Oct 24 2008 ro@suse.de
- drop illegal provides for glibc-devel
* Fri Oct 24 2008 sassmann@suse.de
- resurrect uClibc (version 0.9.29)
  * provide a wrapper script (gcc-uClibc) to reuse our existing
    toolchain for compiling
  * for now only static linking with uClibc possible
